==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Lukukertoja");
define("_BROWSERS","Selaimet");
define("_OPERATINGSYS","Kyttjrjestelmt");
define("_UNKNOWN","tuntematon");
define("_OTHER","Muu / Tuntematon");
define("_MISCSTATS","Sekalaista statiikkaa");
define("_REGUSERS","Rekisterityneit kyttji:");
define("_ACTIVEAUTHORS","Aktiivisia yllpitji:");
define("_STORIESPUBLISHED","Uutista julkaistu:");
define("_SACTIVETOPICS","Aktiivista kanavaa:");
define("_COMMENTSPOSTED","Kommentteja:");
define("_SSPECIALSECT","Opetuksien aihepiirej:");
define("_ARTICLESSEC","Opetuksia aihepiireiss:");
define("_LINKSINLINKS","Linkkej kannassa:");
define("_LINKSCAT","Linkkien kategorioita:");
define("_NEWSWAITING","Uutista odottaa julkaisemista:");
define("_NUKEVERSION","Versio:");
define("_SEARCHENGINES","Hakukoneet");
define("_BOTS","Robotit");
define("_STATS","Statiikka");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Lukukertoja");
define("_BROWSERS","Selaimet");
define("_OPERATINGSYS","Kyttjrjestelmt");
define("_UNKNOWN","tuntematon");
define("_OTHER","Muu / Tuntematon");
define("_MISCSTATS","Sekalaista statiikkaa");
define("_REGUSERS","Rekisterityneit kyttji:");
define("_ACTIVEAUTHORS","Aktiivisia yllpitji:");
define("_STORIESPUBLISHED","Uutista julkaistu:");
define("_SACTIVETOPICS","Aktiivista kanavaa:");
define("_COMMENTSPOSTED","Kommentteja:");
define("_SSPECIALSECT","Opetuksien aihepiirej:");
define("_ARTICLESSEC","Opetuksia aihepiireiss:");
define("_LINKSINLINKS","Linkkej kannassa:");
define("_LINKSCAT","Linkkien kategorioita:");
define("_NEWSWAITING","Uutista odottaa julkaisemista:");
define("_NUKEVERSION","Versio:");
define("_SEARCHENGINES","Hakukoneet");
define("_BOTS","Robotit");
define("_STATS","Statiikka");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
